@@ -591,8 +591,8 @@ class ParseNode:
         else:
             st = "(" + self.data.getName()
             for child in self.children:
-                st += child.__str__()
-            return st + ")"
+                st += " " + child.__str__()
+            return st + ") "
 
     def moveLeft(self, node: ParseNode):
         """
